==> pandoc-citeproc-0.16.4.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-citeproc
version:              0.16.4.1
visibility:           public
id:                   pandoc-citeproc-0.16.4.1-5kFk50DgCgtKc7b8x0unqn
key:                  pandoc-citeproc-0.16.4.1-5kFk50DgCgtKc7b8x0unqn
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Andrea Rossato
homepage:             https://github.com/jgm/pandoc-citeproc
synopsis:             Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.

    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.

    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.

category:             Text
abi:                  38e800dde1678ffaa329abbc9b7e4213
exposed:              True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style

hidden-modules:
    Text.CSL.Util Paths_pandoc_citeproc Text.CSL.Compat.Pandoc

import-dirs:          /usr/lib/ghc-8.8.1/site-local/pandoc-citeproc-0.16.4.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/pandoc-citeproc-0.16.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-citeproc
hs-libraries:         HSpandoc-citeproc-0.16.4.1-5kFk50DgCgtKc7b8x0unqn
depends:
    HsYAML-0.2.1.0-9pU4vi1l50LFaTfTMDUMD1
    HsYAML-aeson-0.2.0.0-2JZAyZfE2MxEQ9H6bv4oUb
    aeson-1.4.6.0-E2BkI4IZQTS95PTQn3BtDE base-4.13.0.0
    bytestring-0.10.9.0 containers-0.6.2.1
    data-default-0.7.1.1-6BHwbWEbMIC6PlzqbJSGwa directory-1.3.3.2
    filepath-1.4.2.1 hs-bibutils-6.7.0.0-DroHauNN2U9JxfqZplAZep
    mtl-2.2.2 network-2.8.0.1-8QQySbZhiIM4MftFWmBCjN
    old-locale-1.0.0.7-KOGgqu8HfWChZyQBUEp1c
    pandoc-2.8-AWROmmsbCrtBa2DVN7Q1LY
    pandoc-types-1.20-DnWB6cf2zysKlCXHkgcUfa parsec-3.1.14.0
    setenv-0.1.1.3-AApHapTZwGVKX9z2HargZZ
    split-0.2.3.3-I9Fligr0MXBCK62zUxnusc
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM
    tagsoup-0.14.8-HNYd7NBl7Y37tM3OCkX65n text-1.2.4.0
    text-icu-0.7.0.1-1I3HLejVSG8BkacPnLl7EW time-1.9.3
    unordered-containers-0.2.10.0-BOyMat0aeilHaccjX66VbF
    vector-0.12.0.3-5jznHM9LsC6GoMm8iesU7Q
    xml-conduit-1.8.0.1-DxMsRj5dNMlDbmCf25fxWv
    yaml-0.11.2.0-9wQclzzlhdBHaG0BhmYKTy

haddock-interfaces:   /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html:         /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-citeproc-0.16.4.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc-citeproc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-citeproc
version:              0.16.4.1
visibility:           public
id:                   pandoc-citeproc-0.16.4.1-9NnTODoDfsTIBpPQwQeZZm
key:                  pandoc-citeproc-0.16.4.1-9NnTODoDfsTIBpPQwQeZZm
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane, Andrea Rossato
homepage:             https://github.com/jgm/pandoc-citeproc
synopsis:             Supports using pandoc with citeproc
description:
    The pandoc-citeproc library supports automatic
    generation of citations and a bibliography in pandoc
    documents using the Citation Style Language (CSL)
    macro language. More details on CSL can be found at
    <http://citationstyles.org/>.

    In addition to a library, the package includes
    an executable, pandoc-citeproc, which works as a pandoc
    filter and also has a mode for converting bibliographic
    databases into CSL JSON and pandoc YAML metadata formats.

    pandoc-citeproc originated as a fork of Andrea
    Rossato'\''s citeproc-hs.

category:             Text
abi:                  e9589eb2dfe3281d34d5aa3eefe287d6
exposed:              True
exposed-modules:
    Text.CSL Text.CSL.Data Text.CSL.Eval Text.CSL.Eval.Common
    Text.CSL.Eval.Date Text.CSL.Eval.Names Text.CSL.Eval.Output
    Text.CSL.Exception Text.CSL.Input.Bibtex Text.CSL.Input.Bibutils
    Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Pandoc
    Text.CSL.Parser Text.CSL.Proc Text.CSL.Proc.Collapse
    Text.CSL.Proc.Disamb Text.CSL.Reference Text.CSL.Style

hidden-modules:
    Text.CSL.Util Paths_pandoc_citeproc Text.CSL.Compat.Pandoc

import-dirs:          /usr/lib/ghc-8.8.1/site-local/pandoc-citeproc-0.16.4.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/pandoc-citeproc-0.16.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc-citeproc
hs-libraries:         HSpandoc-citeproc-0.16.4.1-9NnTODoDfsTIBpPQwQeZZm
depends:
    HsYAML-0.2.1.0-Bwv71B6uk9ZAoLqOsLc3hW
    HsYAML-aeson-0.2.0.0-3a8WI4Gp44g2GdXmoo57yh
    aeson-1.4.6.0-AJ7Yrh9834zKNft31BPLw9 base-4.13.0.0
    bytestring-0.10.9.0 containers-0.6.2.1
    data-default-0.7.1.1-kkFWAw6t22HQTKxCfb2xV directory-1.3.3.2
    filepath-1.4.2.1 hs-bibutils-6.7.0.0-DroHauNN2U9JxfqZplAZep
    mtl-2.2.2 network-2.8.0.1-7k4XOYkWuzJL3fZ1ktoWWP
    old-locale-1.0.0.7-KOGgqu8HfWChZyQBUEp1c
    pandoc-2.8-Lfx9LCUnDV38FtiEZAN8Ez
    pandoc-types-1.20-GPW74CFC0Yt7NP96nCmiOG parsec-3.1.14.0
    setenv-0.1.1.3-AApHapTZwGVKX9z2HargZZ
    split-0.2.3.3-LLnOaLGP9zG6uQmbPyhGdE
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM
    tagsoup-0.14.8-58HmOPIRCkuDBd23ezXSGE text-1.2.4.0
    text-icu-0.7.0.1-1I3HLejVSG8BkacPnLl7EW time-1.9.3
    unordered-containers-0.2.10.0-1f7Z20Tf4OoEec1rJRqjhr
    vector-0.12.0.3-5jznHM9LsC6GoMm8iesU7Q
    xml-conduit-1.8.0.1-ENmIcupANFCGJpRdLxsk4u
    yaml-0.11.2.0-Jfs2EmMZMprFCVFgqvFTz7

haddock-interfaces:   /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
haddock-html:         /usr/share/doc/pandoc-citeproc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
